Animation

Struct Animation 

pub struct Animation {
    pub per_frame_joint_poses: Array3<f32>,
    pub per_frame_root_trans: Array2<f32>,
    pub per_frame_expression_coeffs: Option<Array2<f32>>,
    pub start_offset: usize,
    pub runner: AnimationRunner,
    pub config: AnimationConfig,
}
Animation struct for all data regarding a certain animation

Fields

per_frame_joint_poses: Array3<f32>per_frame_root_trans: Array2<f32>per_frame_expression_coeffs: Option<Array2<f32>>start_offset: usizerunner: AnimationRunnerconfig: AnimationConfig

Implementations

Source

impl Animation

pub fn new_from_matrices( per_frame_joint_poses: Array3<f32>, per_frame_global_trans: Array2<f32>, per_frame_expression_coeffs: Option<Array2<f32>>, config: AnimationConfig, ) -> Self

Panics

Will panic if the translation and rotation do not cover the same number of timesteps

pub fn new_from_npz(anim_npz_path: &str, config: AnimationConfig) -> Self

Panics

Will panic if the path cannot be opened Will panic if the translation and rotation do not cover the same number of timesteps

pub async fn new_from_npz_async( anim_npz_path: &str, config: AnimationConfig, ) -> Self

Panics

Will panic if the path cannot be opened Will panic if the translation and rotation do not cover the same number of timesteps

pub fn new_from_json( path: &str, _anim_fps: f32, config: AnimationConfig, ) -> Self

Panics

Will panic if the path cannot be opened Will panic if the translation and rotation do not cover the same number of timesteps

pub fn new_from_smpl_codec( codec: &SmplCodec, wrap_behaviour: AnimWrap, ) -> Option<Self>

Create an Animation component from a SmplCodec

Panics

Will panic if the individual body part poses in the codec don’t have the correct shape to be concatenated together into a full pose for the whole body

pub fn new_from_smpl_file(path: &str, wrap_behaviour: AnimWrap) -> Option<Self>

Create an Animation component from a .smpl file

pub fn new_from_smpl_buf(buf: &[u8], wrap_behaviour: AnimWrap) -> Option<Self>

Create an Animation component from a .smpl buffer

pub fn num_active_joints(&self) -> usize

pub fn num_animation_frames(&self) -> usize

pub fn advance(&mut self, dt_raw: Duration, first_time: bool)

Advances the animation by the amount of time elapsed since last time we got the current pose

pub fn has_expression(&self) -> bool

pub fn get_smooth_time_indices(&self) -> (usize, usize, f32)

pub fn get_current_pose<B: Backend>(&mut self, use_slerp: bool) -> PoseG<B>

Get the pose and translation at the current time, interpolates if necessary. Using Slerp interpolation is more accurate but also slower. Most of the time when vieweing an animation, it’s enough to use use_slerp=false

pub fn get_pose_at_idx<B: Backend>(&self, idx: usize) -> PoseG<B>

Get pose at a certain frame ID

pub fn get_current_expression(&mut self) -> Option<Expression>

Get expression at current time

pub fn get_expression_at_idx(&self, idx: usize) -> Option<Expression>

Get expression at a given frame ID

pub fn slice_time_range(&self, start_sec: f32, end_sec: f32) -> Animation

pub fn align_y_axis_quadrant( &mut self, current_axis: &Array1<f32>, desired_axis: &Array1<f32>, )

Rotates multiple of 90 until the axis of the body is aligned with some arbitrary vector

pub fn get_cur_time(&self) -> Duration

pub fn set_cur_time_as_sec(&mut self, time_sec: f32)

pub fn pause(&mut self)

pub fn play(&mut self)

pub fn duration(&self) -> Duration

Duration of the animation

pub fn is_finished(&self) -> bool

pub fn nr_repetitions(&self) -> u32

pub fn translate(&mut self, translation: &Array1<f32>) -> Result<(), String>

Shift each frame of the animation by the given translation vector.

Errors

Will return Err for array size mismatch.